@@ -9,13 +9,6 @@ from .taggers import spacy_tagger
 from .search_results import SearchResults
 from .ngrams import NGrams
 from .tables import spacy_taggers
-from .ttr import TTR
-
-# TESTDIR = resource_filename('textelixir', 'test')
-
-# with open(f'{TESTDIR}/test.txt', 'r', encoding='utf-8') as f:
-#     print(f.read())
-
         
 class TextElixir:
     def __init__(self, filename=None, lang='en', elixir_filename=None, **kwargs):
@@ -23,7 +16,6 @@ class TextElixir:
         self.tagger_option = kwargs['tagger_option'] if 'tagger_option' in kwargs else 'stanza:pos'
         self.punct_pos = kwargs['punct_pos'] if 'punct_pos' in kwargs else ['SYM', 'PUNCT', 'SPACE']
         self.verbose = kwargs['verbose'] if 'verbose' in kwargs else True
-        self.chunk_size = kwargs['chunk_size'] if 'chunk_size' in kwargs else 10000
         # Parse args
         self.filename = filename
         self.lang = lang
@@ -160,7 +152,7 @@ class TextElixir:
                     print(output_string, file=file_out)
 
     def create_word_list(self):
-        elixir = pandas.read_csv(f'{self.basename}/corpus.elix', sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size, keep_default_na=False)
+        elixir = pandas.read_csv(f'{self.basename}/corpus.elix', sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000, keep_default_na=False)
         # word_tracking will contain each words. Once it hits correct size or end of sentence, then reset the words.
         categories = ['text', 'lower', 'lemma', 'pos']
         word_dict = {}
@@ -195,15 +187,13 @@ class TextElixir:
     def read_elixir(self):
         if self.verbose:
             print(f'Reading {self.filename}...')
-        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
+        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
         self.word_count = 0
         self.chunk_num = 0
         for chunk in self.elixir:
             self.chunk_num += 1
             normal_words = chunk[~chunk['pos'].isin(self.punct_pos)]
             self.word_count += normal_words.shape[0]
-            print(f'\rRead {self.chunk_num} blocks...', end='')
-        print('\n')
         if self.verbose:
             print(f'{self.word_count} words have been loaded!')
 
@@ -212,7 +202,7 @@ class TextElixir:
         text_filter = kwargs['text_filter'] if 'text_filter' in kwargs else None
         verbose = kwargs['verbose'] if 'verbose' in kwargs else None
         regex = kwargs['regex'] if 'regex' in kwargs else False
-        return SearchResults(self.filename, search_string, self.word_count, punct_pos=self.punct_pos, verbose=verbose, text_filter=text_filter, regex=regex, chunk_size=self.chunk_size)
+        return SearchResults(self.filename, search_string, self.word_count, punct_pos=self.punct_pos, verbose=verbose, text_filter=text_filter, regex=regex)
 
 
     def build_corpus(self, **kwargs):
@@ -243,8 +233,7 @@ class TextElixir:
                       sep=kwargs['sep'] if 'sep' in kwargs else ' ', 
                       text_filter=kwargs['text_filter'] if 'text_filter' in kwargs else None,
                       punct_pos=self.punct_pos, 
-                      chunk_num=self.chunk_num,
-                      chunk_size=self.chunk_size)
+                      chunk_num=self.chunk_num)
 
     # Calculates the ngram frequency list.
     def ngrams(self, size, **kwargs):
@@ -253,11 +242,7 @@ class TextElixir:
                       group_by=kwargs['group_by'] if 'group_by' in kwargs else 'lower', 
                       sep=kwargs['sep'] if 'sep' in kwargs else ' ', 
                       text_filter=kwargs['text_filter'] if 'text_filter' in kwargs else None, 
-                      cross_sentence_boundary = kwargs['cross_sentence_boundary'] if 'cross_sentence_boundary' in kwargs else False,
                       punct_pos=self.punct_pos, 
                       chunk_num=self.chunk_num)
 
-    # Calculates the TTR of the entire corpus or divided into sections.
-    def ttr(self, **kwargs):
-        group_by = kwargs['group_by'] if 'group_by' in kwargs else None
-        return TTR(self.filename, group_by=group_by, punct_pos=self.punct_pos)
+
