@@ -5,15 +5,14 @@ from .kwic import KWIC
 from .collocates import Collocates
 from .sentences import Sentences
 from .vocabdist import VocabDist
+from .getwords import get_previous_word
 
 class SearchResults:
     def __init__(self, filename, search_string, word_count, **kwargs):
-        
         # Parse kwargs
         self.punct_pos = kwargs['punct_pos']
         self.verbose = kwargs['verbose']
         self.text_filter = kwargs['text_filter']
-        self.chunk_size = kwargs['chunk_size']
         # Check for regex within text_filter
         if self.text_filter and 'is_regex' in self.text_filter:
             self.filter_regex = self.text_filter['is_regex']
@@ -41,20 +40,11 @@ class SearchResults:
         elif isinstance(self.search_string, list):
             search_words = self.search_string[0].split(' ')
 
-        if len(search_words) > 1:
-            search_type = 'phrase'
-        else:
-            search_type = 'word'
-        
+        # Set Search Type 'word' || phrase
+        search_type = 'phrase' if len(search_words) > 1 else 'word'
 
         if search_type == 'word':
-            if isinstance(self.search_string, str):
-                word_type, search_word = self.get_word_type(self.search_string)
-                ibrk = 0
-            elif isinstance(self.search_string, list):
-                # Word type is determined by the first word in the search list.
-                word_type, search_word = self.get_word_type(self.search_string[0])
-            
+            word_type, search_word = self.get_word_type(self.search_string) if isinstance(self.search_string, str) else self.get_word_type(self.search_string[0])
             results_indices = self.filter_elixir(self.search_string, word_type)
 
         elif search_type == 'phrase':
@@ -70,7 +60,7 @@ class SearchResults:
                     # Set default distance to 1.
                     distance = 1
                 else:
-                    self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
+                    self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
                     new_indices = []
                     for block_num, chunk in enumerate(self.elixir):
                         # Get the list of the current results indices based on the block number.
@@ -82,12 +72,12 @@ class SearchResults:
                             word_index = int(word_index)
 
                             if curr_block_num != block_num:
-                                ibrk = 0
+                                raise Exception(f'The current block num {curr_block_num} is not the same as block num {block_num}')
 
-                            if block_num == 0:
-                                previous_words = self.get_previous_words(None, chunk, block_num, word_index, curr_block_num, distance)
-                            else:
-                                previous_words = self.get_previous_words(last_chunk, chunk, block_num, word_index, curr_block_num, distance)
+                            last_chunk = last_chunk if block_num != 0 else None
+                            
+                            # Get previous words
+                            previous_words = get_previous_word(last_chunk, chunk, block_num, word_index, distance)
                             
                             # Filter those previous words for good hits.
                             good_hit = None
@@ -154,7 +144,7 @@ class SearchResults:
             results = []
         elif isinstance(search_word, list):
             results = {}
-        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
+        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
         for block_num, chunk in enumerate(self.elixir):
             chunk = chunk.applymap(str)
             chunk = self.filter_chunk(chunk)
@@ -190,18 +180,16 @@ class SearchResults:
                             value = word_specs[wt_idx]
                             found_words = found_words[found_words[wt] == value]
                 for word in found_words.to_dict('index'):
-                    find_index = word-(block_num*self.chunk_size)
+                    find_index = word-(block_num*10000)
                     results.append((f'{block_num}:{find_index}',))
-            # Collocates Handle
+            
+            # Collocates Handler
             elif isinstance(search_word, list):
                 for word in search_word:
                     word_specs = [re.sub(r'^/(.+?)/$', r'\1', w) for w in re.split(r'(?<!\\)_', word)]
                     # TODO: HANLDE WILDCARDS HERE
                     for wt_idx, wt in enumerate(word_type):
-                        if wt_idx == 0:
-                            found_words = chunk[chunk[wt] == word_specs[wt_idx]]
-                        else:
-                            found_words = found_words[found_words[wt] == word_specs[wt_idx]]
+                        found_words = chunk[chunk[wt] == word_specs[wt_idx]] if wt_idx == 0 else found_words[found_words[wt] == word_specs[wt_idx]]
                     if word not in results:
                         results[word] = 0
                     results[word] += len(found_words)
@@ -217,38 +205,6 @@ class SearchResults:
                 filtered_indices.append(index)
         return filtered_indices
 
-    def get_previous_words(self, last_chunk, chunk, block_num, curr_index, curr_block_num, distance, word_list=None):
-        if word_list == None:
-            word_list = []
-        if len(word_list) == distance:
-            return word_list
-
-        # Get the number of the previous word.
-        find_index = curr_index-1
-        
-        if find_index < 0:
-            find_index = self.chunk_size+curr_index-1
-            # If last_chunk is None, then we are at the beginning of block 0.
-            if last_chunk is None:
-                return word_list
-            # Otherwise, we can check the last chunk to get the next word.
-            previous_word = last_chunk.iloc[find_index]
-            used_block_num = block_num-1
-        else:
-            previous_word = chunk.iloc[find_index]
-            used_block_num = block_num
-
-
-        # If the pos is PUNCT, let's ignore it and continue to the next word.
-        if previous_word['pos'] == 'PUNCT':
-            word_list = self.get_previous_words(last_chunk, chunk, block_num, curr_index-1, curr_block_num, distance, word_list)
-        else:
-            word_list.append({f'{used_block_num}:{find_index}': previous_word})
-        if len(word_list) != distance:
-            word_list = self.get_previous_words(last_chunk, chunk, block_num, curr_index-1, curr_block_num, distance, word_list)
-
-        return word_list
-
     # Filters the chunk based on optional filters.
     def filter_chunk(self, chunk):
         if self.text_filter == None:
@@ -327,13 +283,17 @@ class SearchResults:
     ### VOCABULARY DISTRIBUTION HANDLER
     def vocab_distribution(self, **kwargs):
         group_by = kwargs['group_by'] if 'group_by' in kwargs else 0
-        return VocabDist(self.filename, group_by, self.results_indices, self.punct_pos, self.search_string, self.chunk_size)
+        return VocabDist(self.filename, group_by, self.results_indices, self.punct_pos, self.search_string)
 
     ### KWIC LINES HANDLER
     def kwic_lines(self, before=5, after=5, group_by='lower'):
         return KWIC(self.filename, self.results_indices, before=before, after=after, group_by=group_by, search_string=self.search_string, punct_pos=self.punct_pos)
 
 
+    ### KWIC LINES ALIAS
+    def concordance_lines(self, before=5, after=5, group_by='lower'):
+        return KWIC(self.filename, self.results_indices, before=before, after=after, group_by=group_by, search_string=self.search_string, punct_pos=self.punct_pos)
+
     ### COLLOCATES HANDLER
     def collocates(self, before=5, after=5, group_by='lemma_pos', mi_threshold=3, sample_size_threshold=2):
         ### ERROR HANDLING
@@ -343,7 +303,7 @@ class SearchResults:
         if group_by not in ['lemma', 'lower', 'pos', 'lower_pos', 'lemma_pos']:
             raise Exception(f"{{group_by}} value is invalid. It must be lemma, lower, pos, lower_pos, or lemma_pos.")
 
-        collocates = Collocates(self.filename, self.results_indices, before, after, self.word_count, group_by, mi_threshold=mi_threshold, sample_size_threshold=sample_size_threshold, search_string=self.search_string, chunk_size=self.chunk_size)
+        collocates = Collocates(self.filename, self.results_indices, before, after, self.word_count, group_by, mi_threshold=mi_threshold, sample_size_threshold=sample_size_threshold, search_string=self.search_string)
         # Set the totals for each word that was found as a collocate. This cannot be done in collocates.py because it depends on search_results.py, which also depends on collocates.py
         collocates.set_total(self.calculate_collocate_totals(collocates.sample))
         # Once totals are available, statistics can be calculated.
@@ -354,12 +314,9 @@ class SearchResults:
         print('Getting totals for each collocating word.')
         totals = {}
         words = [word for word, value in samples.items()]
-        totals = SearchResults(self.filename, words, self.word_count, punct_pos=self.punct_pos, verbose=False, text_filter=None, regex=False, chunk_size=self.chunk_size).results_totals
+        totals = SearchResults(self.filename, words, self.word_count, punct_pos=self.punct_pos, verbose=False, text_filter=None, regex=False).results_totals
         return totals
 
     ### SENTENCES HANDLER
     def sentences(self, group_by='text'):
-        return Sentences(self.filename, self.results_indices, group_by=group_by, search_string=self.search_string, chunk_size=self.chunk_size)
-
-    ### Frequency Distribution
-    # 
\ No newline at end of file
+        return Sentences(self.filename, self.results_indices, group_by=group_by, search_string=self.search_string)
