@@ -1,22 +1,22 @@
+from lib2to3.pytree import convert
 import pandas
 import plotly.express as px
 
 class VocabDist:
-    def __init__(self, filename, group_by=0, results_indices=None, punct_pos=None, search_string='', chunk_size=10000):
+    def __init__(self, filename, group_by=0, results_indices=None, punct_pos=None, search_string=''):
         self.filename = filename
         self.group_by = group_by
         self.results_indices = results_indices
         self.search_length = len(self.results_indices[0])
         self.punct_pos = punct_pos
         self.search_string =search_string
-        self.chunk_szie = chunk_size
         self.data = self.calculate_distribution()
         self.data = self.add_totals(self.data)
         self.data = self.add_expected(self.data)
         self.data = self.add_normalized_freq(self.data)
 
     def calculate_distribution(self):
-        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
+        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
         data = {}
         convert_to_str_list = []
         for block_num, chunk in enumerate(self.elixir):
@@ -51,7 +51,7 @@ class VocabDist:
 
     
     def add_totals(self, data):
-        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
+        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
         for block_num, chunk in enumerate(self.elixir):
             # Eliminate punctuation from the ch
             filtered_chunk = chunk[~chunk['pos'].isin(self.punct_pos)]
